==> cp2k_2025.1.orig.tar.gz: cp2k-2025.1/docs/acronyms.md <==
# Acronyms

```{glossary}
ADMM
    Auxiliary Density Matrix Method [→ more](methods/dft/hartree-fock/admm)

ALMO
    Absolutely Localized Molecular Orbitals

AM1
    Austin Model 1 [→ more](methods/semiempiricals/index)

AMBER
    Assisted Model Building and Energy Refinement

ASE
    Atomic Simulation Environment

ASPC
    Always Stable Predictor-Corrector [→ more](methods/sampling/molecular_dynamics)

BFGS
    Broyden–Fletcher–Goldfarb–Shanno algorithm [→ more](methods/optimization/geometry)

BOMD
    Born-Oppenheimer Molecular Dynamics [→ more](methods/sampling/molecular_dynamics)

BSSE
    Basis Set Superposition Error [→ more](methods/dft/basis_sets)

CDFT
    Constrained Density Functional Theory  [→ more](methods/dft/constrained)

CDFT-CI
    Constrained Density Functional Theory Configuration Interaction [→ more](methods/dft/constrained)

CG
    Conjugated Gradients algorithm [→ more](methods/optimization/geometry)

CHARMM
    Chemistry at HARvard Molecular Mechanics

COLVAR
    COLlective VARiable [→ more](methods/sampling/metadynamics)

CP
    Car-Parrinello method

CPMD
    Car-Parrinello Molecular Dynamics

CSVR
    Canonical Sampling through Velocity Rescaling

CUDA
    Compute Unified Device Architecture

DBCSR
    Distributed Block Compressed Sparse Row library

DDAPC
    Density Derived Atomic Point Charges

DFTB
    Density Functional Tight Binding [→ more](methods/semiempiricals/dftb)

DFT
    Density Functional Theory [→ more](methods/dft/index)

DFET
    Density Functional Embedding Theory [→ more](methods/embedding/qm_qm)

DIIS
    Direct Inversion of the Iterative Subspace [→ more](methods/dft/index)

DLA-F
    Distributed Linear Algebra from the Future [→ more](technologies/eigensolvers/dlaf)

DOS
    Density Of States

EAM
    Embedded-Atom Method

EC
    Energy Correction

EIP
    Empirical Interatomic Potential [→ more](methods/semiempiricals/index)

ELPA
    Eigenvalue soLvers for Petascale Applications [→ more](technologies/eigensolvers/elpa)

EMD
    Ehrenfest Molecular Dynamics [→ more](methods/sampling/ehrenfest)

EPR
    Electron Paramagnetic Resonance

ERI
    Electron Repulsion Integral [→ more](methods/dft/hartree-fock/index)

FCC
    Face-Centered Cubic crystal structure

FIST
    Frontiers In Simulation Technology (CP2K's force field implementation)

FPGA
    Field Programmable Gate Array

GAPW
    Gaussian Augmented-Plane Waves method [→ more](methods/dft/gapw)

GEEP
    Gaussian Expansion of the Electrostatic Potential [→ more](methods/qm_mm/builtin)

GGA
    Generalized Gradient Approximations [→ more](methods/dft/index)

GHO
    Generalized Hybrid Orbital method

GLE
    Generalized Langevin Equation thermostat

GPW
    Gaussian Plane Wave method [→ more](methods/dft/gpw)

GROMOS
    GROningen MOlecular Simulation

GTH
    Goedecker-Teter-Hutter pseudopotentials

GTO
    Gaussian Type Orbitals

HF
    Hartree Fock [→ more](methods/dft/hartree-fock/index)

HFX
    Hartree Fock eXchange [→ more](methods/dft/hartree-fock/index)

HIP
    Heterogeneous Interface for Portability

IEEE
    Institute of Electrical and Electronics Engineers

IMOMM
    Integrated Molecular Orbital Molecular Mechanics method

KS
    Kohn-Sham [→ more](methods/dft/index)

LCAO
    Linear Combination of Atomic Orbitals

LDA
    Local-Density Approximation [→ more](methods/dft/index)

LDOS
    Local Density of States.

LINRES
    LINear RESponse

LRIGPW
    Local Resolution-of-Identity Projector Augmented Wave method [→ more](methods/dft/local_ri)

LS
    Linear Scaling [→ more](methods/dft/linear_scaling)

LSD
    Local Spin Density

MAO
    Modified Atomic Orbitals

MC
    Monte Carlo method [→ more](methods/sampling/monte_carlo)

MD
    Molecular Dynamics [→ more](methods/sampling/molecular_dynamics)

MM
    Molecular Mechanics

MME
    MiniMax-Ewald [→ more](methods/qm_mm/image_charges)

MNDO
    Modified Neglect of Diatomic Overlap

MO
    Molecular Orbitals [→ more](methods/dft/index)

MOM
    Maximum Overlap Method

MP2
    Møller–Plesset perturbation theory to 2nd order [→ more](methods/post_hartree_fock/mp2)

MPI
    Message Passing Interface

MSST
    Multi-Scale Shock Technique

NDDO
    Neglect of Diatomic Differential Overlap

NEB
    Nudged Elastic Band [→ more](methods/optimization/nudged_elastic_band)

NEGF
    Non-Equilibrium Green's Function [→ more](methods/properties/bandstructure_gw)

NMR
    Nuclear Magnetic Resonance [→ more](methods/properties/nmr)

NNP
    Neural Network Potential [→ more](methods/machine_learning/nnp)

NpE
    Constant Number, Pressure, and Energy [→ more](methods/sampling/molecular_dynamics)

NVE
    Constant Number, Volume, and Energy [→ more](methods/sampling/molecular_dynamics)

NVT
    Constant Number, Volume, and Temperature [→ more](methods/sampling/molecular_dynamics)

OF
    Orbital Free [→ more](methods/dft/index)

OpenCL
    Open Computing Language

OpenMP
    Open Multi-Processing

OT
    Orbital Transformation method

PAO-ML
    Polarized Atomic Orbitals from Machine Learning [→ more](methods/machine_learning/pao-ml)

PBC
    Periodic Boundary Conditions

PBE
    Perdew–Burke–Ernzerhof exchange-correlation functional [→ more](methods/dft/index)

PIGLET
    Path Integral Generalized Langevin Equation Thermostat

PILE
    Path Integral Langevin Equation thermostat

PINT
    Path INTegral [→ more](methods/sampling/path_integrals)

PM3
    Parameterized Model number 3 [→ more](methods/semiempiricals/index)

PM6
    Parameterized Model number 6 [→ more](methods/semiempiricals/index)

POD
    Projection-Operator Diabatization

PP
    Pseudo-Potential [→ more](methods/dft/pseudopotentials)

PW
    Plane Waves

QMMM
    Quantum Mechanics / Molecular Mechanics [→ more](methods/qm_mm/index)

QM
    Quantum Mechanics

QS
    Quick Step (cp2k's quantum methods implementation) [→ more](methods/dft/gpw)

RESP
    Restrained ElectroStatic Potential [→ more](methods/properties/resp_charges)

RESPA
    REversible reference System Propagator Algorithm

RI
    Resolution of Identity

RM1
    Recife Model 1

RMA
    Remote Memory Access

RMSD
    Root-Mean-Square Deviation

RPA
    Random-Phase Approximation [→ more](methods/post_hartree_fock/rpa)

RPMD
    Ring Polymer Molecular Dynamics [→ more](methods/sampling/path_integrals)

SCCS
    Self-Consistent Continuum Solvation model [→ more](methods/qm_mm/implicit_solvation)

SCF
    Self Consistent Field algorithm [→ more](methods/dft/index)

SCPTB
    Self-Consistent-Polarization Tight-Binding

SE
    Semi-Empirical methods [→ more](methods/semiempiricals/index)

SIC
    Self Interaction Correction

SOC
    Spin-Orbit Couplings

STM
    Scanning Tunneling Microscope [→ more](methods/properties/stm_images)

TDDFPT
    Time Dependent Density Field Perturbation Theory [→ more](methods/properties/optical/tddft)

TMC
    Tree Monte Carlo algorithm

TRS4
    TRace reSetting 4th order scheme [→ more](methods/dft/linear_scaling)

UFF
    Universal Force Field

XAS
    X-ray Absorption Spectra [→ more](methods/properties/x-ray/index)

XC
    eXchange and Correlation functional [→ more](methods/dft/index)

xTB
    eXtended Tight Binding [→ more](methods/semiempiricals/xtb)

ZMP
    Zhao-Morrison-Parr potential

```

==> cp2k_2025.2.orig.tar.gz: cp2k-2025.2/docs/acronyms.md <==
# Acronyms

```{glossary}
ADMM
    Auxiliary Density Matrix Method [→ more](methods/dft/hartree-fock/admm)

ALMO
    Absolutely Localized Molecular Orbitals

AM1
    Austin Model 1 [→ more](methods/semiempiricals/index)

AMBER
    Assisted Model Building and Energy Refinement

APT
    Atomic Polarization Tensor

ASE
    Atomic Simulation Environment

ASPC
    Always Stable Predictor-Corrector [→ more](methods/sampling/molecular_dynamics)

BFGS
    Broyden–Fletcher–Goldfarb–Shanno algorithm [→ more](methods/optimization/geometry)

BOMD
    Born-Oppenheimer Molecular Dynamics [→ more](methods/sampling/molecular_dynamics)

BSE
    Bethe-Salpeter Equation [→ more](methods/properties/optical/bethe-salpeter)

BSSE
    Basis Set Superposition Error [→ more](methods/dft/basis_sets)

CDFT
    Constrained Density Functional Theory  [→ more](methods/dft/constrained)

CDFT-CI
    Constrained Density Functional Theory Configuration Interaction [→ more](methods/dft/constrained)

CG
    Conjugated Gradients algorithm [→ more](methods/optimization/geometry)

CHARMM
    Chemistry at HARvard Molecular Mechanics

COLVAR
    COLlective VARiable [→ more](methods/sampling/metadynamics)

CP
    Car-Parrinello method

CPMD
    Car-Parrinello Molecular Dynamics

CSVR
    Canonical Sampling through Velocity Rescaling

CUDA
    Compute Unified Device Architecture

DBCSR
    Distributed Block Compressed Sparse Row library

DDAPC
    Density Derived Atomic Point Charges

DFTB
    Density Functional Tight Binding [→ more](methods/semiempiricals/dftb)

DFT
    Density Functional Theory [→ more](methods/dft/index)

DFET
    Density Functional Embedding Theory [→ more](methods/embedding/qm_qm)

DIIS
    Direct Inversion of the Iterative Subspace [→ more](methods/dft/index)

DLA-F
    Distributed Linear Algebra from the Future [→ more](technologies/eigensolvers/dlaf)

DOS
    Density Of States

EAM
    Embedded-Atom Method

EC
    Energy Correction

EHT
    Extended Hückel Theory

EIP
    Empirical Interatomic Potential [→ more](methods/semiempiricals/index)

ELPA
    Eigenvalue soLvers for Petascale Applications [→ more](technologies/eigensolvers/elpa)

EMD
    Ehrenfest Molecular Dynamics [→ more](methods/sampling/ehrenfest)

EPR
    Electron Paramagnetic Resonance

ERI
    Electron Repulsion Integral [→ more](methods/dft/hartree-fock/index)

FCC
    Face-Centered Cubic crystal structure

FIST
    Frontiers In Simulation Technology (CP2K's force field implementation)

FPGA
    Field Programmable Gate Array

GAPW
    Gaussian Augmented-Plane Waves method [→ more](methods/dft/gapw)

gCP
    Geometrical CounterPoise [→ more](#Kruse2012)

GCP
    Google Cloud Platform [→ more](https://cloud.google.com)

GEEP
    Gaussian Expansion of the Electrostatic Potential [→ more](methods/qm_mm/builtin)

GGA
    Generalized Gradient Approximations [→ more](methods/dft/index)

GHO
    Generalized Hybrid Orbital method

GLE
    Generalized Langevin Equation thermostat

GPW
    Gaussian Plane Wave method [→ more](methods/dft/gpw)

GROMOS
    GROningen MOlecular Simulation

GTH
    Goedecker-Teter-Hutter pseudopotentials

GTO
    Gaussian Type Orbitals

GW
    GW approximation [→ more](methods/properties/optical/index)

HF
    Hartree Fock [→ more](methods/dft/hartree-fock/index)

HFX
    Hartree Fock eXchange [→ more](methods/dft/hartree-fock/index)

HIP
    Heterogeneous Interface for Portability

IEEE
    Institute of Electrical and Electronics Engineers

IMOMM
    Integrated Molecular Orbital Molecular Mechanics method

K-point
    a vector in reciprocal space [→ more](methods/dft/k-points)

KS
    Kohn-Sham [→ more](methods/dft/index)

LCAO
    Linear Combination of Atomic Orbitals

LDA
    Local-Density Approximation [→ more](methods/dft/index)

LDOS
    Local Density of States.

LINRES
    LINear RESponse

LRIGPW
    Local Resolution-of-Identity Projector Augmented Wave method [→ more](methods/dft/local_ri)

LS
    Linear Scaling [→ more](methods/dft/linear_scaling)

LSD
    Local Spin Density

MAO
    Modified Atomic Orbitals

MC
    Monte Carlo method [→ more](methods/sampling/monte_carlo)

MD
    Molecular Dynamics [→ more](methods/sampling/molecular_dynamics)

MM
    Molecular Mechanics

MME
    MiniMax-Ewald [→ more](methods/qm_mm/image_charges)

MNDO
    Modified Neglect of Diatomic Overlap

MO
    Molecular Orbitals [→ more](methods/dft/index)

MOM
    Maximum Overlap Method

MP2
    Møller–Plesset perturbation theory to 2nd order [→ more](methods/post_hartree_fock/mp2)

MPI
    Message Passing Interface

MSST
    Multi-Scale Shock Technique

NDDO
    Neglect of Diatomic Differential Overlap

NEB
    Nudged Elastic Band [→ more](methods/optimization/nudged_elastic_band)

NEGF
    Non-Equilibrium Green's Function [→ more](methods/properties/bandstructure_gw)

NMR
    Nuclear Magnetic Resonance [→ more](methods/properties/nmr)

NNP
    Neural Network Potential [→ more](methods/machine_learning/nnp)

NpE
    Constant Number, Pressure, and Energy [→ more](methods/sampling/molecular_dynamics)

NVE
    Constant Number, Volume, and Energy [→ more](methods/sampling/molecular_dynamics)

NVT
    Constant Number, Volume, and Temperature [→ more](methods/sampling/molecular_dynamics)

OF
    Orbital Free [→ more](methods/dft/index)

OpenCL
    Open Computing Language

OpenMP
    Open Multi-Processing

OT
    Orbital Transformation method

PAO-ML
    Polarized Atomic Orbitals from Machine Learning [→ more](methods/machine_learning/pao-ml)

PBC
    Periodic Boundary Conditions

PBE
    Perdew–Burke–Ernzerhof exchange-correlation functional [→ more](methods/dft/index)

PIGLET
    Path Integral Generalized Langevin Equation Thermostat

PILE
    Path Integral Langevin Equation thermostat

PINT
    Path INTegral [→ more](methods/sampling/path_integrals)

PM3
    Parameterized Model number 3 [→ more](methods/semiempiricals/index)

PM6
    Parameterized Model number 6 [→ more](methods/semiempiricals/index)

POD
    Projection-Operator Diabatization

PP
    Pseudo-Potential [→ more](methods/dft/pseudopotentials)

PW
    Plane Waves

QMMM
    Quantum Mechanics / Molecular Mechanics [→ more](methods/qm_mm/index)

QM
    Quantum Mechanics

QS
    Quick Step (cp2k's quantum methods implementation) [→ more](methods/dft/gpw)

RESP
    Restrained ElectroStatic Potential [→ more](methods/properties/resp_charges)

RESPA
    REversible reference System Propagator Algorithm

RI
    Resolution of Identity

RM1
    Recife Model 1

RMA
    Remote Memory Access

RMSD
    Root-Mean-Square Deviation

RPA
    Random-Phase Approximation [→ more](methods/post_hartree_fock/rpa)

RPMD
    Ring Polymer Molecular Dynamics [→ more](methods/sampling/path_integrals)

SCCS
    Self-Consistent Continuum Solvation model [→ more](methods/qm_mm/implicit_solvation)

SCF
    Self Consistent Field algorithm [→ more](methods/dft/index)

SCPTB
    Self-Consistent-Polarization Tight-Binding

SE
    Semi-Empirical methods [→ more](methods/semiempiricals/index)

SIC
    Self Interaction Correction

SOC
    Spin-Orbit Couplings

STM
    Scanning Tunneling Microscope [→ more](methods/properties/stm_images)

TDDFPT
    Time Dependent Density Field Perturbation Theory [→ more](methods/properties/optical/tddft)

TMC
    Tree Monte Carlo algorithm

TRS4
    TRace reSetting 4th order scheme [→ more](methods/dft/linear_scaling)

UFF
    Universal Force Field

XAS
    X-ray Absorption Spectra [→ more](methods/properties/x-ray/index)

XC
    eXchange and Correlation functional [→ more](methods/dft/index)

xTB
    eXtended Tight Binding [→ more](methods/semiempiricals/xtb)

Z-matrix
    formalism to represent atomic coordinates [→ more](https://en.wikipedia.org/wiki/Z-matrix_(chemistry))

ZMP
    Zhao-Morrison-Parr potential
```
